@@ -139,7 +139,12 @@ class Revision(Enum):
 
     FIX_BALANCE_BUG = 11
 
-    LATEST = 11
+    BURN_V2_ENABLED = 12
+    IMPROVED_PRE_VALIDATOR = 12
+    VERIFY_ASSET_INTEGRITY = 12
+    USE_RLP = 12
+
+    LATEST = 12
 
 
 RC_DB_VERSION_0 = 0
@@ -224,6 +229,10 @@ class ConfigKey:
 
     UNSTAKE_SLOT_MAX = "unstakeSlotMax"
 
+    # The list of items(address, unstake, unstake_block_height)
+    # containing invalid expired unstakes to remove
+    INVALID_EXPIRED_UNSTAKES_PATH = "invalidExpiredUnstakesPath"
+
 
 class EnableThreadFlag(IntFlag):
     INVOKE = 1
@@ -468,3 +477,18 @@ class RPCMethod:
     ICX_CALL = 'icx_call'
     ICX_SEND_TRANSACTION = 'icx_sendTransaction'
     DEBUG_ESTIMATE_STEP = "debug_estimateStep"
+    DEBUG_GET_ACCOUNT = "debug_getAccount"
+
+
+class DataType:
+    CALL = "call"
+    DEPLOY = "deploy"
+    DEPOSIT = "deposit"
+    MESSAGE = "message"
+    NONE = None
+
+    _TYPES = {CALL, DEPLOY, DEPOSIT, MESSAGE, NONE}
+
+    @classmethod
+    def contains(cls, value: str) -> bool:
+        return value in cls._TYPES
